pub struct Mapping {
pub to_internal: Vec<Option<Symbol>>,
pub to_external: Vec<Symbol>,
}Expand description
Contains maps for translation between internal and external symbols.
Fields
to_internal: Vec<Option<Symbol>>An array of internal symbols, indexed by external symbol ID.
to_external: Vec<Symbol>An array of external symbols, indexed by internal symbol ID.
Implementations