SymbolSource

Struct SymbolSource 

pub struct SymbolSource<T: SymbolPrimitive = NonZeroU32> { /* private fields */ }
A source of numeric symbols.

Implementations

Source

impl<T: SymbolPrimitive> SymbolSource<T>

pub fn new() -> Self

Creates a source of numeric symbols with an empty symbol space.

pub fn sym<'a, const N: usize>(&mut self) -> [Symbol<T>; N]

Returns generated symbols.

pub fn with_names<'a, const N: usize, S: Into<Cow<'static, str>>>( &mut self, names: [Option<S>; N], ) -> [Symbol<T>; N]

Returns generated symbols.

pub fn next_sym(&mut self, name: Option<Cow<'_, str>>) -> Symbol<T>

Generates a new unique symbol.

pub fn name_of(&self, sym: Symbol) -> Cow<'_, str>

Returns either the formatted name if the given Symbol is a gensym, or the Symbol’s exact name.

Gensyms have no names. That’s why we create a ‘formatted’ name with the letter g followed by the symbol’s numeric value.

pub fn original_name_of(&self, sym: Symbol) -> Option<&str>

Returns the exact name, or None if the Symbol has no name (i.e. is a gensym).

pub fn num_syms(&self) -> usize

Returns the number of symbols in use.

pub fn generate(&mut self) -> impl Iterator<Item = Symbol<T>> + use<'_, T>

Returns an iterator that generates symbols.

pub fn generate_fresh() -> impl Iterator<Item = Symbol<T>>

Iterator over all possible Symbols, in order, starting with the lowest numeric value.

pub fn remap_symbols<F>(&mut self, map: F)
where F: FnMut(Symbol<T>) -> Symbol<T>,

Translates symbol names according to the given mapping beween Symbols.

pub fn truncate(&mut self, new_len: usize)

Removes all the symbols with numeric value equal or higher than the argument.

Panics

Panics unless new_len is within 1 ..= T::MAX.

pub fn names(&self) -> Vec<Option<SymbolName>>

Returns the list of Symbol names.

Performance

Internally, bumps the reference count for every existing SymbolName and copies the pointers to a newly allocated a new Vec,

pub fn name_map(&self) -> HashMap<SymbolName, Symbol>

Creates a HashMap where you can access a Symbol through its name.